==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage invalid" : "Ógild gagnageymsla",
    "Unknown error" : "Óþekkt villa",
    "All files" : "Allar skrár",
    "Saved" : "Vistað",
    "There was an error saving" : "Villa kom upp við vistun",
    "File could not be found" : "Þessi skrá fannst ekki",
    "Home" : "Heim",
    "Close" : "Loka",
    "Favorites" : "Eftirlæti",
    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
    "Upload cancelled." : "Hætt við innsendingu.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
    "Target folder does not exist any more" : "Markmappan er ekki lengur til",
    "Not enough free space" : "Ekki nægilegt pláss",
    "Uploading..." : "Sendi inn ...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Innsending í gangi. Ef þú ferð af þessari síðu mun innsending hætta.",
    "Actions" : "Aðgerðir",
    "Download" : "Niðurhal",
    "Rename" : "Endurnefna",
    "Delete" : "Eyða",
    "Disconnect storage" : "Aftengja gagnageymslu",
    "Unshare" : "Hætta deilingu",
    "Could not load info for file \"{file}\"" : "Gat ekki hlaðið inn upplýsingum fyrir skrána \"{file}\"",
    "Files" : "Skrár",
    "Details" : "Nánar",
    "Select" : "Velja",
    "Pending" : "Í bið",
    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
    "Invalid path" : "Ógild slóð",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu annálana eða hafðu samband við kerfissjóra",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "{newName} already exists" : "{newName} er þegar til",
    "Could not rename \"{fileName}\", it does not exist any more" : "Gat ekki endurnefnt \"{fileName}\", það er ekki lengur til staðar",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{targetName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
    "No entries in this folder match {filter}" : "Engar færslur í þessari möppu samsvara {filter}",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
    "New" : "Nýtt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" er með óleyfilega skráategund/skráarendingu.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
    "Path" : "Slóð",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Favorited" : "Sett í eftirlæti",
    "Favorite" : "Eftirlæti",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Einkatengilll: Aðeins fólk sem hefur aðgang að skránni/möppunni getur notað hann. Notaðu hann sem varanlegan tengil fyrir sjálfan þig eða til að beina öðrum á skrár innan sameigna.",
    "Folder" : "Mappa",
    "New folder" : "Ný mappa",
    "{newname} already exists" : "{newname} er þegar til",
    "Upload" : "Senda inn",
    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
    "A file or folder has been <strong>changed</strong>" : "Skjali eða möppu hefur verið <strong>breytt</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
    "You created %1$s" : "Þú bjóst til %1$s",
    "%2$s created %1$s" : "%2$s bjó til %1$s",
    "%1$s was created in a public folder" : "%1$s var búið til í opinni möppu",
    "You changed %1$s" : "Þú breyttir %1$s",
    "%2$s changed %1$s" : "%2$s breytti %1$s",
    "You deleted %1$s" : "Þú eyddir %1$s",
    "%2$s deleted %1$s" : "%2$s eyddi %1$s",
    "You restored %1$s" : "Þú endurheimtir %1$s",
    "%2$s restored %1$s" : "%2$s endurheimti %1$s",
    "Changed by %2$s" : "Breytt af %2$s",
    "Deleted by %2$s" : "Eytt af %2$s",
    "Restored by %2$s" : "Endurheimt af %2$s",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "File handling" : "Meðhöndlun skráar",
    "Maximum upload size" : "Hámarksstærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Með PHP-FPM getur það tekið 5 mínútur fyrir breytingar að verða virkar.",
    "Missing permissions to edit from here." : "Vantar heimildir til að breyta einhverju héðan.",
    "Settings" : "Stillingar",
    "Show hidden files" : "Sýna faldar skrár",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nálgast skrárnar þínar með WebDAV</a>",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "No favorites" : "Engin eftirlæti",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem uppáhald birtast hér",
    "Text file" : "Textaskrá",
    "New text file.txt" : "Ný textaskrá.txt"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage invalid" : "Ógild gagnageymsla",
    "Unknown error" : "Óþekkt villa",
    "All files" : "Allar skrár",
    "Saved" : "Vistað",
    "There was an error saving" : "Villa kom upp við vistun",
    "File could not be found" : "Þessi skrá fannst ekki",
    "Home" : "Heim",
    "Close" : "Loka",
    "Favorites" : "Eftirlæti",
    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
    "Upload cancelled." : "Hætt við innsendingu.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
    "Target folder does not exist any more" : "Markmappan er ekki lengur til",
    "Not enough free space" : "Ekki nægilegt pláss",
    "Uploading..." : "Sendi inn ...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Innsending í gangi. Ef þú ferð af þessari síðu mun innsending hætta.",
    "Actions" : "Aðgerðir",
    "Download" : "Niðurhal",
    "Rename" : "Endurnefna",
    "Delete" : "Eyða",
    "Disconnect storage" : "Aftengja gagnageymslu",
    "Unshare" : "Hætta deilingu",
    "Could not load info for file \"{file}\"" : "Gat ekki hlaðið inn upplýsingum fyrir skrána \"{file}\"",
    "Files" : "Skrár",
    "Details" : "Nánar",
    "Select" : "Velja",
    "Pending" : "Í bið",
    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
    "Invalid path" : "Ógild slóð",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu annálana eða hafðu samband við kerfissjóra",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "{newName} already exists" : "{newName} er þegar til",
    "Could not rename \"{fileName}\", it does not exist any more" : "Gat ekki endurnefnt \"{fileName}\", það er ekki lengur til staðar",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{targetName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
    "No entries in this folder match {filter}" : "Engar færslur í þessari möppu samsvara {filter}",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
    "New" : "Nýtt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" er með óleyfilega skráategund/skráarendingu.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
    "Path" : "Slóð",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Favorited" : "Sett í eftirlæti",
    "Favorite" : "Eftirlæti",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Einkatengilll: Aðeins fólk sem hefur aðgang að skránni/möppunni getur notað hann. Notaðu hann sem varanlegan tengil fyrir sjálfan þig eða til að beina öðrum á skrár innan sameigna.",
    "Folder" : "Mappa",
    "New folder" : "Ný mappa",
    "{newname} already exists" : "{newname} er þegar til",
    "Upload" : "Senda inn",
    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
    "A file or folder has been <strong>changed</strong>" : "Skjali eða möppu hefur verið <strong>breytt</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
    "You created %1$s" : "Þú bjóst til %1$s",
    "%2$s created %1$s" : "%2$s bjó til %1$s",
    "%1$s was created in a public folder" : "%1$s var búið til í opinni möppu",
    "You changed %1$s" : "Þú breyttir %1$s",
    "%2$s changed %1$s" : "%2$s breytti %1$s",
    "You deleted %1$s" : "Þú eyddir %1$s",
    "%2$s deleted %1$s" : "%2$s eyddi %1$s",
    "You restored %1$s" : "Þú endurheimtir %1$s",
    "%2$s restored %1$s" : "%2$s endurheimti %1$s",
    "Changed by %2$s" : "Breytt af %2$s",
    "Deleted by %2$s" : "Eytt af %2$s",
    "Restored by %2$s" : "Endurheimt af %2$s",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "File handling" : "Meðhöndlun skráar",
    "Maximum upload size" : "Hámarksstærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Með PHP-FPM getur það tekið 5 mínútur fyrir breytingar að verða virkar.",
    "Missing permissions to edit from here." : "Vantar heimildir til að breyta einhverju héðan.",
    "Settings" : "Stillingar",
    "Show hidden files" : "Sýna faldar skrár",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nálgast skrárnar þínar með WebDAV</a>",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "No favorites" : "Engin eftirlæti",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem uppáhald birtast hér",
    "Text file" : "Textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "Upload timeout for file \"{file}\"" : "Tímamörk innsendingar fyrir skrána \"{file}\"",
    "Processing files..." : "Meðhöndla skrár...",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Þú hefur ekki aðgangsheimildir til að skoða þessa skrá/möppu. Hafðu samband við eigandann og biddu hann um að deila þessu með þér.",
    "Error when assembling chunks, status code {status}" : "Villa við að setja saman búta, stöðukóði {status}"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
